@@ -122,6 +122,7 @@
 #' @seealso \code{\link{dataList.Chakra.Web.orderd} } \code{\link{d} }
 #'
 #' @name dataList.Chakra.Web
+#  dataList.Chakra.Web ----
 #' @docType data
 #' @author Issei Tsunoda \email{tsunoda.issei1111@gmail.com }
 #'
@@ -169,9 +170,13 @@ NULL
 
 
 #' @title Multiple Reader and Multiple Modality Data
-#' @description A list, representing FROC data of MRMC.
-#' @details This data is based on in Chakraborty's JAFROC software in which example data exists. The author have calculated hits and false alarms from this Jafroc example data.
-
+#' @description A list, representing FROC data of MRMC. This is same as \code{\link{dataList.Chakra.Web} }.
+#' @details This data is based on in Chakraborty's JAFROC software
+#' in which example data exists.
+#'  The author have calculated hits and false alarms
+#'  from this Jafroc example data.
+#'
+#'
 #'
 #'\strong{\emph{ Contents:  }}
 #'
@@ -293,6 +298,7 @@ NULL
 #'   \code{\link{d} }
 #'
 #' @name dd
+# dd -------
 #' @docType data
 #' @author Issei Tsunoda \email{tsunoda.issei1111@gmail.com }
 #'
@@ -302,6 +308,74 @@ NULL
 #'
 #'     viewdata(BayesianFROC::dd)
 #'
+#'
+# ####1#### ####2#### ####3#### ####4#### ####5#### ####6#### ####7#### ####8#### ####9####
+#'#----------------------------------------------------------------------------------------
+#'#   dd  is same as dataList.Chakra.Web,  since the following code is all TRUE
+#'#----------------------------------------------------------------------------------------
+#'
+#'     dd$f==dataList.Chakra.Web$f
+#'
+#'
+#'
+#'
+#'
+#'
+#'
+# ####1#### ####2#### ####3#### ####4#### ####5#### ####6#### ####7#### ####8#### ####9####
+#'#----------------------------------------------------------------------------------------
+#'#                           Code to make the dataset dd
+#'#----------------------------------------------------------------------------------------
+#'
+#'
+#'
+#'
+#'
+#'
+#' h<-c(
+#'   50,30,11,5,1,15,29,29,1,0,39,31,8 ,10,3,10,8 ,25,45,14, # modality 1
+#'   52,25,13,4,1,27,28,29,1,0,53,29,13,2 ,4,9 ,16,22,43,14, # modality 2
+#'   43,29,11,6,0,18,29,21,0,0,43,29,6 ,7 ,1,10,14,19,32,23, # modality 3
+#'   61,19,12,9,3,16,29,34,1,0,52,29,10,4 ,3,10,16,23,43,15, # modality 4
+#'   35,29,18,9,0,17,27,24,0,0,34,33,7 ,13,2,12,16,21,35,15  # modality 5
+#' )
+#'
+#' f <-c(
+#'   0 ,4,20,29,21,0,0,6,15,22,1 ,15,18,31,19,1,2,4,16,17,# modality 1
+#'   1 ,1,21,24,23,1,1,5,30,40,2 ,19,31,56,42,2,0,2,30,32,# modality 2
+#'   1, 7,13,28,19,0,1,7, 7,31, 7,15,28,41,9 ,0,2,5,24,31,# modality 3
+#'   1, 4,18,21,23,1,1,0,11,35, 6,14,37,36,18,0,2,4,18,25,# modality 4
+#'   0, 2,19,23,18,0,2,6,10,30, 2,25,40,29,24,1,1,4,24,32)# modality 5
+#'
+#' a   <- m_q_c_vector_from_M_Q_C(5,4,5)
+#'
+#' m <- a$m
+#' c <- a$c
+#' q <- a$q
+#'
+#' NI<-199
+#' NL <-142
+#' C<-5
+#' M<-5
+#' Q<-4
+#'
+#' dd <- list(
+#'   h=h,
+#'   f=f,
+#'   m=m,
+#'   c=c,
+#'   q=q,
+#'   NI=NI,
+#'   NL=NL,
+#'   M=M,
+#'   Q=Q,
+#'   C=C
+#' )
+#'
+#'
+#'
+#'
+#'
 
 NULL
 
@@ -323,6 +397,215 @@ NULL
 
 
 
+#' @title Multiple Reader and Multiple Modality Data
+#' @description A list, representing FROC data of MRMC. This is same as \code{\link{dataList.Chakra.Web} }.
+#' @details This data is based on in Chakraborty's JAFROC software
+#' in which example data exists.
+#'  The author have calculated hits and false alarms
+#'  from this Jafroc example data.
+#'  Moreover the author ordered it such that the modality ID  also means
+#'  its observer performance, namely Modality ID = 1 means it has the most high AUC.
+#'
+#'
+#' @name dd.orderd
+# dd.orderd -------
+#' @docType data
+#' @author Issei Tsunoda \email{tsunoda.issei1111@gmail.com }
+#'
+#cat(tabular(data.frame(m=dd.orderd$m,q=dd.orderd$q,c=dd.orderd$c,h=dd.orderd$h,f=dd.orderd$f)))
+#' @section contents:
+#'  \tabular{ccccc}{
+#'  \strong{ModalityID } \tab   \strong{ReaderID }  \tab  \strong{ Confidence levels} \tab   \strong{No. of hits} \tab \strong{No. of false alarms} \cr
+
+
+
+
+#' \code{m} \tab \code{q} \tab \code{c} \tab \code{h} \tab  \code{f}\cr
+#'   -------------- \tab ------------- \tab ------------------------ \tab  ------------------- \tab ----------------\cr
+
+#'
+#' 1 \tab 1 \tab 5 \tab 61 \tab  1\cr
+#' 1 \tab 1 \tab 4 \tab 19 \tab  4\cr
+#' 1 \tab 1 \tab 3 \tab 12 \tab 18\cr
+#' 1 \tab 1 \tab 2 \tab  9 \tab 21\cr
+#' 1 \tab 1 \tab 1 \tab  3 \tab 23\cr
+#' 1 \tab 2 \tab 5 \tab 16 \tab  1\cr
+#' 1 \tab 2 \tab 4 \tab 29 \tab  1\cr
+#' 1 \tab 2 \tab 3 \tab 34 \tab  0\cr
+#' 1 \tab 2 \tab 2 \tab  1 \tab 11\cr
+#' 1 \tab 2 \tab 1 \tab  0 \tab 35\cr
+#' 1 \tab 3 \tab 5 \tab 52 \tab  6\cr
+#' 1 \tab 3 \tab 4 \tab 29 \tab 14\cr
+#' 1 \tab 3 \tab 3 \tab 10 \tab 37\cr
+#' 1 \tab 3 \tab 2 \tab  4 \tab 36\cr
+#' 1 \tab 3 \tab 1 \tab  3 \tab 18\cr
+#' 1 \tab 4 \tab 5 \tab 10 \tab  0\cr
+#' 1 \tab 4 \tab 4 \tab 16 \tab  2\cr
+#' 1 \tab 4 \tab 3 \tab 23 \tab  4\cr
+#' 1 \tab 4 \tab 2 \tab 43 \tab 18\cr
+#' 1 \tab 4 \tab 1 \tab 15 \tab 25\cr
+#' 2 \tab 1 \tab 5 \tab 52 \tab  1\cr
+#' 2 \tab 1 \tab 4 \tab 25 \tab  1\cr
+#' 2 \tab 1 \tab 3 \tab 13 \tab 21\cr
+#' 2 \tab 1 \tab 2 \tab  4 \tab 24\cr
+#' 2 \tab 1 \tab 1 \tab  1 \tab 23\cr
+#' 2 \tab 2 \tab 5 \tab 27 \tab  1\cr
+#' 2 \tab 2 \tab 4 \tab 28 \tab  1\cr
+#' 2 \tab 2 \tab 3 \tab 29 \tab  5\cr
+#' 2 \tab 2 \tab 2 \tab  1 \tab 30\cr
+#' 2 \tab 2 \tab 1 \tab  0 \tab 40\cr
+#' 2 \tab 3 \tab 5 \tab 53 \tab  2\cr
+#' 2 \tab 3 \tab 4 \tab 29 \tab 19\cr
+#' 2 \tab 3 \tab 3 \tab 13 \tab 31\cr
+#' 2 \tab 3 \tab 2 \tab  2 \tab 56\cr
+#' 2 \tab 3 \tab 1 \tab  4 \tab 42\cr
+#' 2 \tab 4 \tab 5 \tab  9 \tab  2\cr
+#' 2 \tab 4 \tab 4 \tab 16 \tab  0\cr
+#' 2 \tab 4 \tab 3 \tab 22 \tab  2\cr
+#' 2 \tab 4 \tab 2 \tab 43 \tab 30\cr
+#' 2 \tab 4 \tab 1 \tab 14 \tab 32\cr
+#' 3 \tab 1 \tab 5 \tab 50 \tab  0\cr
+#' 3 \tab 1 \tab 4 \tab 30 \tab  4\cr
+#' 3 \tab 1 \tab 3 \tab 11 \tab 20\cr
+#' 3 \tab 1 \tab 2 \tab  5 \tab 29\cr
+#' 3 \tab 1 \tab 1 \tab  1 \tab 21\cr
+#' 3 \tab 2 \tab 5 \tab 15 \tab  0\cr
+#' 3 \tab 2 \tab 4 \tab 29 \tab  0\cr
+#' 3 \tab 2 \tab 3 \tab 29 \tab  6\cr
+#' 3 \tab 2 \tab 2 \tab  1 \tab 15\cr
+#' 3 \tab 2 \tab 1 \tab  0 \tab 22\cr
+#' 3 \tab 3 \tab 5 \tab 39 \tab  1\cr
+#' 3 \tab 3 \tab 4 \tab 31 \tab 15\cr
+#' 3 \tab 3 \tab 3 \tab  8 \tab 18\cr
+#' 3 \tab 3 \tab 2 \tab 10 \tab 31\cr
+#' 3 \tab 3 \tab 1 \tab  3 \tab 19\cr
+#' 3 \tab 4 \tab 5 \tab 10 \tab  1\cr
+#' 3 \tab 4 \tab 4 \tab  8 \tab  2\cr
+#' 3 \tab 4 \tab 3 \tab 25 \tab  4\cr
+#' 3 \tab 4 \tab 2 \tab 45 \tab 16\cr
+#' 3 \tab 4 \tab 1 \tab 14 \tab 17\cr
+#' 4 \tab 1 \tab 5 \tab 35 \tab  0\cr
+#' 4 \tab 1 \tab 4 \tab 29 \tab  2\cr
+#' 4 \tab 1 \tab 3 \tab 18 \tab 19\cr
+#' 4 \tab 1 \tab 2 \tab  9 \tab 23\cr
+#' 4 \tab 1 \tab 1 \tab  0 \tab 18\cr
+#' 4 \tab 2 \tab 5 \tab 17 \tab  0\cr
+#' 4 \tab 2 \tab 4 \tab 27 \tab  2\cr
+#' 4 \tab 2 \tab 3 \tab 24 \tab  6\cr
+#' 4 \tab 2 \tab 2 \tab  0 \tab 10\cr
+#' 4 \tab 2 \tab 1 \tab  0 \tab 30\cr
+#' 4 \tab 3 \tab 5 \tab 34 \tab  2\cr
+#' 4 \tab 3 \tab 4 \tab 33 \tab 25\cr
+#' 4 \tab 3 \tab 3 \tab  7 \tab 40\cr
+#' 4 \tab 3 \tab 2 \tab 13 \tab 29\cr
+#' 4 \tab 3 \tab 1 \tab  2 \tab 24\cr
+#' 4 \tab 4 \tab 5 \tab 12 \tab  1\cr
+#' 4 \tab 4 \tab 4 \tab 16 \tab  1\cr
+#' 4 \tab 4 \tab 3 \tab 21 \tab  4\cr
+#' 4 \tab 4 \tab 2 \tab 35 \tab 24\cr
+#' 4 \tab 4 \tab 1 \tab 15 \tab 32\cr
+#' 5 \tab 1 \tab 5 \tab 43 \tab  1\cr
+#' 5 \tab 1 \tab 4 \tab 29 \tab  7\cr
+#' 5 \tab 1 \tab 3 \tab 11 \tab 13\cr
+#' 5 \tab 1 \tab 2 \tab  6 \tab 28\cr
+#' 5 \tab 1 \tab 1 \tab  0 \tab 19\cr
+#' 5 \tab 2 \tab 5 \tab 18 \tab  0\cr
+#' 5 \tab 2 \tab 4 \tab 29 \tab  1\cr
+#' 5 \tab 2 \tab 3 \tab 21 \tab  7\cr
+#' 5 \tab 2 \tab 2 \tab  0 \tab  7\cr
+#' 5 \tab 2 \tab 1 \tab  0 \tab 31\cr
+#' 5 \tab 3 \tab 5 \tab 43 \tab  7\cr
+#' 5 \tab 3 \tab 4 \tab 29 \tab 15\cr
+#' 5 \tab 3 \tab 3 \tab  6 \tab 28\cr
+#' 5 \tab 3 \tab 2 \tab  7 \tab 41\cr
+#' 5 \tab 3 \tab 1 \tab  1 \tab  9\cr
+#' 5 \tab 4 \tab 5 \tab 10 \tab  0\cr
+#' 5 \tab 4 \tab 4 \tab 14 \tab  2\cr
+#' 5 \tab 4 \tab 3 \tab 19 \tab  5\cr
+#' 5 \tab 4 \tab 2 \tab 32 \tab 24\cr
+#' 5 \tab 4 \tab 1 \tab 23 \tab 31
+#' }
+#'
+#' @references Example data of Jafroc software
+#' @examples
+#'
+#'
+#'     viewdata(BayesianFROC::dd.orderd)
+#'
+
+#'
+#'
+#'
+#'
+#'
+#'
+#'
+# ####1#### ####2#### ####3#### ####4#### ####5#### ####6#### ####7#### ####8#### ####9####
+#'#----------------------------------------------------------------------------------------
+#'#                           Code to make the dataset dd
+#'#----------------------------------------------------------------------------------------
+#'
+#'
+#' h<-c(
+#'   61,19,12,9,3,16,29,34,1,0,52,29,10,4 ,3,10,16,23,43,15, # modality 4 of dataset dd
+#'   52,25,13,4,1,27,28,29,1,0,53,29,13,2 ,4,9 ,16,22,43,14, # modality 2 of dataset dd
+#'   50,30,11,5,1,15,29,29,1,0,39,31,8 ,10,3,10,8 ,25,45,14, # modality 1 of dataset dd
+#'   35,29,18,9,0,17,27,24,0,0,34,33,7 ,13,2,12,16,21,35,15,  # modality 5 of dataset dd
+#'   43,29,11,6,0,18,29,21,0,0,43,29,6 ,7 ,1,10,14,19,32,23 # modality 3   of dataset dd
+#'
+#' )
+#'
+#' f <-c(
+#'   1, 4,18,21,23,1,1,0,11,35, 6,14,37,36,18,0,2,4,18,25,# modality 4  of dataset dd
+#'   1 ,1,21,24,23,1,1,5,30,40,2 ,19,31,56,42,2,0,2,30,32,# modality 2 of dataset dd
+#'   0 ,4,20,29,21,0,0,6,15,22,1 ,15,18,31,19,1,2,4,16,17,# modality 1 of dataset dd
+#'   0, 2,19,23,18,0,2,6,10,30, 2,25,40,29,24,1,1,4,24,32,# modality 5 of dataset dd
+#'   1, 7,13,28,19,0,1,7, 7,31, 7,15,28,41,9 ,0,2,5,24,31# modality 3 of dataset dd
+#'
+#' )
+#'
+#' a   <- m_q_c_vector_from_M_Q_C(5,4,5)
+#'
+#' m <- a$m
+#' c <- a$c
+#' q <- a$q
+#'
+#' NI<-199
+#' NL <-142
+#' C<-5
+#' M<-5
+#' Q<-4
+#'
+#' dd.orderd <- list(
+#'   h=h,
+#'   f=f,
+#'   m=m,
+#'   c=c,
+#'   q=q,
+#'   NI=NI,
+#'   NL=NL,
+#'   M=M,
+#'   Q=Q,
+#'   C=C
+#' )
+NULL
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 
 
@@ -471,12 +754,13 @@ NULL
 #' @seealso \code{\link{dataList.Chakra.Web} } \code{\link{d} }
 #'
 #' @name dataList.Chakra.Web.orderd
+#  dataList.Chakra.Web.orderd ----------
 #' @docType data
 #' @author Issei Tsunoda \email{tsunoda.issei1111@gmail.com }
 #'
 #' @references Maximum likelihood analysis of free-response  receiver operating characteristic (FROC) data, Dev P. Chakraborty.
 #'
-#  @keywords Single reader and Single modality data. Non-hierarchical FROC data.
+#  @keywords A Single reader and A Single modality data. Non-hierarchical FROC data.
 # devtools::document();help(dataList.Chakra.1)
 NULL
 
@@ -496,11 +780,12 @@ NULL
 #' @description This is used to build a hierarchical FROC model.
 #' @details This data is fictitious.
 #' @name  data.hier.ficitious
+# data.hier.ficitious ---------
 #' @docType data
 #' @author Issei Tsunoda \email{tsunoda.issei1111@gmail.com }
 #'
 #' @references The author' preprint
-#  @keywords Single reader and Single modality data. Non-hierarchical FROC data.
+#  @keywords A Single reader and A Single modality data. Non-hierarchical FROC data.
 # devtools::document();help(dataList.Chakra.1)
 NULL
 
@@ -514,7 +799,6 @@ NULL
 #'
 #' @references Maximum likelihood analysis of free-response  receiver operating characteristic (FROC) data, Dev P. Chakraborty.
 #'
-#  @keywords Single reader and Single modality data. Hierarchical FROC data.
 # devtools::document();help(dataList.Chakra.1)
 NULL
 
@@ -524,6 +808,7 @@ NULL
 #' @description This is used to build a hierarchical FROC model.
 #' @details This data contains only one modality. If see = 12, then the model has converged.
 #' @name  dataList.one.modality
+# dataList.one.modality-------------
 #' @docType data
 #' @author Issei Tsunoda \email{tsunoda.issei1111@gmail.com }
 #'
@@ -542,16 +827,23 @@ NULL
 #' @title Multiple reader and Multiple modality data
 #' @description This is a subset of \code{ \link{dd}}
 #'
+#' This dataset has different dimesion for each moality and reader and confidence levels.
+#' To confirm my program is correct, the author made this.
 #'
+#' In  the following I emphasis that this data set has different dimensions:
+#'\strong{  Different numbers   } \emph{ Different numbers     } \strong{  Different numbers   } \emph{ Different numbers     } \strong{  Different numbers   } \emph{ Different numbers     }
+#'\strong{  Different numbers   } \emph{ Different numbers     } \strong{  Different numbers   } \emph{ Different numbers     } \strong{  Different numbers   } \emph{ Different numbers     }
+
 #' \describe{
 #'
-#'\strong{  Different numbers   } \emph{   }
-#'
-#'\item{ ddd$M   }{  3 modalities   }
 #'\item{ ddd$C   }{   5 Confidence levels }
+#'\item{ ddd$M   }{  3 modalities   }
 #'\item{ ddd$Q   }{    4 readers}
 #'}
 #'
+#'\strong{  Different numbers   } \emph{ Different numbers     } \strong{  Different numbers   } \emph{ Different numbers     } \strong{  Different numbers   } \emph{ Different numbers     }
+#'\strong{  Different numbers   } \emph{ Different numbers     } \strong{  Different numbers   } \emph{ Different numbers     } \strong{  Different numbers   } \emph{ Different numbers     }
+#'
 #' So, all number, i.e. \code{M,C,Q} is \emph{different} each other and this is the reason why the author made this dataset.
 #'
 #'
@@ -562,9 +854,10 @@ NULL
 #' \strong{Contents of dd}
 #'
 #'
-#'  NL = 142(Number of Lesions)
-#'
+#'  \code{NL}  = 142 (Number of Lesions)
 #'
+#'  \code{NI} = 199 (Number of Images)
+
 #'
 #'
 #'
@@ -694,13 +987,19 @@ NULL
 #'            Q=max(dddd$q)
 #'         )
 #'
-#'
-#'
+# ####1#### ####2#### ####3#### ####4#### ####5#### ####6#### ####7#### ####8#### ####9####
+#'#----------------------------------------------------------------------------------------
+#'#           the following gives convergence seed 2019 Oct 12
+#'#----------------------------------------------------------------------------------------
+#' \donttest{
+#' f <- fit_Bayesian_FROC( ite  = 1111, cha = 1, summary = T, dataList = ddd ,see = 123456)
+#'}
 #'
 #'
 #'
 #'
 #' @name  ddd
+# ddd---------------
 #' @docType data
 #' @author Issei Tsunoda \email{tsunoda.issei1111@gmail.com }
 #'
@@ -752,9 +1051,9 @@ NULL
 #' \strong{Contents of dddd}
 #'
 #'
-#'  NL = 142(Number of Lesions)
-#'
+#'  \code{NL}  = 142 (Number of Lesions)
 #'
+#'  \code{NI} = 199 (Number of Images)
 #'
 #'
 #'
@@ -803,6 +1102,8 @@ NULL
 #'   \code{\link{dd} }
 #'
 #' @name dddd
+#'
+# dddd -----------
 #' @docType data
 #' @author Issei Tsunoda \email{tsunoda.issei1111@gmail.com }
 #' @details The reason why the author made this data \code{dddd} is it has only one reader.
@@ -908,20 +1209,29 @@ NULL
 
 
 
-#' @title Multiple reader and one modality
+#' @title MRMC; Model \strong{ \emph{ did not }} converge both null model
+#' @name ddddd
+#  ddddd ------
+
 #' @description This is a subset of \code{ \link{dd}}
+#' In the past, this model did not converge in the \strong{Model_MRMC.stan},
+#' thus I made the new stan file to get convergence estimates and
+#'  named the stan file \emph{Model_Hiera_OneModalityMultipleReader_TargetFormulation.stan}.
+#' Thus, even if the number of modalityt is 1, we can pool the AUCs over all readers by using this new model.
+#' The author believes this pooling is the most natural, primitive, simple way.
+#'
 #'
 #'
 #' \describe{
 #'
 #'\strong{     } \emph{ }
 #'
-#'\item{ ddddd$M   }{  1 modalities   }
-#'\item{ ddddd$C   }{   5 Confidence levels }
-#'\item{ ddddd$Q   }{    4 readers}
+#'\item{ ddddd$M   }{ \strong{ \emph{ 1  }}  modality   }
+#'\item{ ddddd$C   }{  \strong{ \emph{ 5 }}    Confidence levels }
+#'\item{ ddddd$Q   }{   \strong{ \emph{ 4 }}   readers}
 #'}
 #'
-#'@details The model did not converge both null model and alternative model in 2019 Jun 21.
+#'@details The model \strong{ \emph{ did not }} converge both null model and alternative model in 2019 Jun 21.
 
 #'
 #'
@@ -930,8 +1240,9 @@ NULL
 #' \strong{Contents of dddd}
 #'
 #'
-#'  NL = 142(Number of Lesions)
+#'  \code{NL}  = 142 (Number of Lesions)
 #'
+#'  \code{NI} = 199 (Number of Images)#'
 #'
 #'
 #'
@@ -979,7 +1290,6 @@ NULL
 #'  \code{\link{dataList.Chakra.Web.orderd} }
 #'   \code{\link{dd} }
 #'
-#' @name ddddd
 #' @docType data
 #' @author Issei Tsunoda \email{tsunoda.issei1111@gmail.com }
 #'
@@ -1024,6 +1334,26 @@ NULL
 #'           ddddd <-ddd
 #'
 #'
+#'
+#'
+#' \donttest{
+#'
+#'#----------------------------------------------------------------------------------------
+#'#                      Pool AUCs over all readers
+#'#----------------------------------------------------------------------------------------
+#'
+#'
+#'   fit <- fit_Bayesian_FROC(ddddd)
+#'
+#'   DrawCurves(fit,readerID = c(1,2,3,4))
+#'
+#'
+#'#  With pain 2019 Sept 29
+#'}
+#'
+#'
+#'
+#'
 NULL
 
 
@@ -1043,6 +1373,9 @@ NULL
 
 
 #' @title Multiple reader and one modality data
+#' @name dddddd
+# dddddd------------
+
 #' @description This is a subset of \code{ \link{dd}}
 #'
 #'
@@ -1064,8 +1397,9 @@ NULL
 #' \strong{Contents of dddddd}
 #'
 #'
-#'  NL = 142(Number of Lesions)
+#'  \code{NL}  = 142 (Number of Lesions)
 #'
+#'  \code{NI} = 199 (Number of Images)#'
 #'
 #'
 #'
@@ -1103,7 +1437,6 @@ NULL
 #'  \code{\link{dataList.Chakra.Web.orderd} }
 #'   \code{\link{dd} }
 #'
-#' @name dddddd
 #' @docType data
 #' @author Issei Tsunoda \email{tsunoda.issei1111@gmail.com }
 #'
@@ -1247,8 +1580,9 @@ NULL
 #' \strong{Contents of dddddd}
 #'
 #'
-#'  NL = 142(Number of Lesions)
+#'  \code{NL}  = 142 (Number of Lesions)
 #'
+#'  \code{NI} = 199 (Number of Images)#'
 #'
 #'
 #'
@@ -1267,6 +1601,7 @@ NULL
 #'  Not \code{\link{dd} }
 #'
 #' @name ddddddd
+# ddddddd ---------
 #' @docType data
 #' @author Issei Tsunoda \email{tsunoda.issei1111@gmail.com }
 #'
@@ -1384,5 +1719,19 @@ NULL
 NULL
 
 
+tabular <- function(df, ...) {
+  stopifnot(is.data.frame(df))
+
+  align <- function(x) if (is.numeric(x)) "r" else "l"
+  col_align <- vapply(df, align, character(1))
+
+  cols <- lapply(df, format, ...)
+  contents <- do.call("paste",
+                      c(cols, list(sep = " \\tab ", collapse = "\\cr\n  ")))
+
+  paste("\\tabular{", paste(col_align, collapse = ""), "}{\n  ",
+        contents, "\n}\n", sep = "")
+}
 
 
+# Using this return value, we obtain cat or message( return), then it available on roxygen2
